cjs.lnl=function(par,imat,Phi.dm,p.dm,Phi.fixed=NULL,p.fixed=NULL,debug=FALSE,
		time.intervals=NULL,all=FALSE)
###################################################################################
# cjs.lnl - computes -2*log likelihood value of cjs model using call to FORTRAN
#            subroutine
#
# Arguments:
#    par             - vector of parameter values to evaluate likelihood
#    imat            - list of indicator vectors, frequency etc from process.ch
#    Phi.dm          - Phi design matrix created by call to create.dm
#    p.dm            - p design matrix created by call to create.dm
#    Phi.fixed       - matrix with 3 columns: ch number(i), occasion number(j), fixed value(f)
#                       to fix phi(i,j)=f 
#    p.fixed         - matrix with 3 columns: ch number(i), occasion number(j), fixed value(f)
#                       to fix p(i,j)=f 
#    debug           - if TRUE show iterations with par and -2lnl
#    time.intervals  - intervals of time between occasions
#    all             - if TRUE, returns entire lnl computation list
#
# Value: -2*log likelihood
##################################################################################
{
	func_eval<<-func_eval+1
	if(debug)cat("\npar = ",par)
	nocc=imat$nocc
	nphi=ncol(Phi.dm)
	np=ncol(p.dm)
	beta.phi=par[1:nphi]
	beta.p=par[(nphi+1):(nphi+np)]
	Phibeta=matrix(as.vector(Phi.dm%*%beta.phi),ncol=nocc-1,nrow=nrow(Phi.dm)/(nocc-1),byrow=TRUE)
	pbeta=matrix(as.vector(p.dm%*%beta.p),ncol=nocc-1,nrow=nrow(p.dm)/(nocc-1),byrow=TRUE)
	if(is.null(time.intervals))time.intervals=rep(1,nocc-1)
	lnl=.Fortran("cjs",as.double(imat$chmat),as.double(Phibeta),as.double(pbeta),
			as.double(imat$first),as.double(imat$last),as.double(imat$freq),
			as.integer(imat$loc),as.double(Phi.fixed),as.double(p.fixed),
			as.double(time.intervals),as.integer(nrow(imat$chmat)),           
			as.integer(ncol(imat$chmat)),as.integer(nrow(Phi.fixed)),
			as.integer(nrow(p.fixed)),lnl=double(1),p0=double(nrow(imat$chmat)),PACKAGE="RMark")
	if(debug)
	{
		cat("\nlnl = ",lnl$lnl)
	} else
	if((func_eval-100*floor(func_eval/100))==0)
	{
		string=paste("Number of evaluations: ",func_eval," -lnl:",formatC(lnl$lnl,digits=6))
		cat(paste(paste(rep("\8",nchar(string)),collapse=""),string,sep=""))
		flush.console()
	}	
	if(all)
		return(lnl)
	else
		return(lnl$lnl)
}
